###################################################################################################
# zmsteaserelement.py
#
# Implementation of class ZMSTeaserElement (see below).
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################

# Imports.
from Globals import HTML, HTMLFile
import string 
import urllib
import time
# Product Imports.
from zmsobject import ZMSObject
import _blobfields
import _globals


###################################################################################################
###################################################################################################
###   
###   C o n s t r u c t o r ( s )
###   
###################################################################################################
###################################################################################################

def manage_addZMSTeaserElement(self, lang, manage_lang, _sort_id, REQUEST):
  """ manage_addZMSTeaserElement """
  
  ##### Create ####
  id_prefix = _globals.id_prefix(REQUEST.get('id','e'))
  obj = ZMSTeaserElement(self.getNewId(id_prefix),_sort_id+1)
  self._setObject(obj.id, obj)
    
  obj = getattr(self,obj.id)
  ##### VersionManager ####
  obj.setObjStateNew(REQUEST)
  ##### Init Coverage ####
  coverage = self.getDCCoverage(REQUEST)
  if coverage.find('local.')==0:
    obj.setObjProperty('attr_dc_coverage',coverage)
  else:
    obj.setObjProperty('attr_dc_coverage','global.'+lang)
  ##### Init Properties ####
  for s_lang in self.getLanguages():
    obj.setObjProperty('active',1,s_lang)
  ##### VersionManager ####
  obj.onChangeObj(REQUEST)
            
  ##### Normalize Sort-IDs ####
  self.normalizeSortIds(id_prefix)
        
  # Return with message.        
  if REQUEST.RESPONSE:
    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))


###################################################################################################

lstPenetrance = [
  0,'this',
  1,'sub_nav',
  2,'sub_all'
]

###################################################################################################
###################################################################################################
###   
###   C l a s s
###   
###################################################################################################
###################################################################################################

class ZMSTeaserElement(ZMSObject): 
        
    # Properties.
    # -----------
    meta_type = "ZMSTeaserElement"
    icon = "misc_/zms/zmsteaser.gif"
    icon_disabled = "misc_/zms/zmsteaser_disabled.gif"

    # Management Options.
    # -------------------
    manage_options = ( 
	{'label': 'TAB_EDIT',    'action': 'manage_main'},
	{'label': 'TAB_HISTORY', 'action': 'manage_UndoVersionForm'},
	)

    # Management Permissions.
    # -----------------------
    __authorPermissions__ = (
		'manage','manage_main',
		'manage_properties','manage_changeProperties',
		'manage_moveObjUp','manage_moveObjDown',
		'manage_cutObjects','manage_copyObjects','manage_pasteObjs',
		'manage_rollbackVersionChanges','manage_requestVersionChanges',
		)
    __editorPermissions__ = (
		'manage_commitVersionChanges',
		)
    __administratorPermissions__ = (
		)
    __ac_permissions__=(
		('ZMS Author', __authorPermissions__),
		('ZMS Editor', __editorPermissions__),
		('ZMS Administrator', __administratorPermissions__),
		)

    # Properties.
    # -----------
    __obj_attrs__ = {
        # Changed by
        'change_uid':{'datatype':'string','multilang':1,'xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        'change_dt':{'datatype':'datetime','multilang':1,'xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        # Properties
        'sort_id':{'datatype':'string','xml':0},
        'active':{'datatype':'boolean','multilang':1},
        'attr_active_start':{'datatype':'datetime','multilang':1},
        'attr_active_end':{'datatype':'datetime','multilang':1},
        'title':{'datatype':'string','multilang':1,'size':40},
        'text':{'datatype':'string','multilang':1,'type':'text','size':50},
        'textalign':{'datatype':'string','default':'LEFT'},
        'displaytype':{'datatype':'int','default':2},
        'attr_penetrance':{'datatype':'int','type':'select','options':lstPenetrance},
        'attr_url':{'datatype':'url','multilang':1},
        'attr_img':{'datatype':'image','multilang':1},
        # Meta-Data
        'attr_dc_coverage':{'datatype':'string'},
    }


    # Management Interface.
    manage_main = HTMLFile('dtml/zmsteaserelement/manage_main',globals()) 


    """
    ###############################################################################################    
    #
    #   CONSTRUCTOR
    #
    ###############################################################################################    
    """

    # -------------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.recurse_updateVersion:
    #
    #  Update version.
    # -------------------------------------------------------------------------------------------------
    def recurse_updateVersion(self, REQUEST):
      message = ''

      # Process super-objects.
      message = message + ZMSObject.recurse_updateVersion(self,REQUEST)
        
      # Process object.
      # [...]
            
      # Return with message.
      return message


    """
    ###############################################################################################    
    #
    #   Eigenschaften
    #
    ###############################################################################################    
    """

    ###############################################################################################
    #  ZMSTeaserElement.manage_changeProperties: 
    #
    #  Change Teaser properties.
    ###############################################################################################
    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE): 
      """ ZMSTeaserElement.manage_changeProperties """
        
      message = ''
      if REQUEST.get('btn','') != self.getLangStr('BTN_CANCEL',manage_lang):
        
        ##### Object State #####
        self.setObjStateModified(REQUEST)
            
        ##### Properties #####
        for key in self.getObjAttrs().keys():
          self.setReqProperty(key,REQUEST)

        ##### Blobs #####
        _blobfields.synchronizeBlobFields(self)
          
        ##### VersionManager ####
        self.onChangeObj(REQUEST)
          
	##### Message #####
        message = self.getLangStr('MSG_CHANGED',manage_lang)
        
      # Return with message.
      self.checkIn(REQUEST)
      RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))

    # ---------------------------------------------------------------------------------------------
    #  ZMSCustom.getPenetrance
    # ---------------------------------------------------------------------------------------------
    def getPenetrance(self, REQUEST):
      penetrance = self.getObjProperty('attr_penetrance',REQUEST)
      return penetrance

    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.getText
    # ---------------------------------------------------------------------------------------------
    def getText(self, REQUEST): 
      text = self.getObjProperty('text',REQUEST)
      # Process html <form>-tags.
      text = _globals.form_quote(text,REQUEST)
      # Return.
      return text

    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.getTitle
    # ---------------------------------------------------------------------------------------------
    def getTitle(self, REQUEST): return self.getObjProperty('title',REQUEST)

    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.getAbstract
    # ---------------------------------------------------------------------------------------------
    def getAbstract(self, REQUEST): return self.search_quote(self.getText(REQUEST))

    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.getImg
    # ---------------------------------------------------------------------------------------------
    def getImg(self, REQUEST): return self.getObjProperty('attr_img',REQUEST)

    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.getUrl
    # ---------------------------------------------------------------------------------------------
    def getUrl(self, REQUEST): return self.getLinkUrl(self.getObjProperty('attr_url',REQUEST),REQUEST)

    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.getTitlealt:
    # ---------------------------------------------------------------------------------------------
    def getTitlealt(self,REQUEST): return self.display_type(REQUEST)


    """
    ###############################################################################################    
    ###  
    ###  HTML-Darstellung 
    ### 
    ###############################################################################################    
    """    

    # preload display interface
    rendershort_default = HTMLFile('dtml/zmsteaserelement/rendershort_default', globals()) 
    
    # ---------------------------------------------------------------------------------------------
    #  ZMSTeaserElement.renderShort:
    #
    #  Renders short presentation of Teaser-Element.
    # ---------------------------------------------------------------------------------------------
    def renderShort(self, REQUEST):
        html = ''
        # Retrieve properties.
        s_title = self.getTitle(REQUEST)
        #-- STEP 1
        # Retrieve properties.
        displaytype  = self.getObjProperty('displaytype',REQUEST,2)
        imgattr      = 'attr_img'
        imghiresattr = None
        imgalign     = self.getObjProperty('textalign',REQUEST,'LEFT')
        imgurl       = self.getUrl(REQUEST)
        imgtarget    = ''
        imgthumb     = 1
        imgspecial   = ''
        imgclass     = None
        textalign    = self.getObjProperty('textalign',REQUEST)
        textformat   = None
        textclass    = "teaserTitle"
        text         = s_title
        if imgurl: 
          if not string.find(imgurl,REQUEST['BASE0']) == 0:
            imgtarget = ' target="_blank"'
          text = '<a href="%s"%s class="teaserTitle">%s</a>'%(imgurl,imgtarget,text)
        text = '<p class="%s">%s</p>'%(textclass,text)
        # Render <html>-presentation.
        html = self.renderDisplaytype(displaytype,imgattr,imghiresattr,imgalign,imgurl,imgthumb,imgspecial,imgclass,text,textalign,textformat,textclass,REQUEST)
        #-- STEP 2
        # Retrieve properties.
        url = imgurl
        target = imgtarget
        title = html
        text = self.getText(REQUEST)
        textclass   = "teaserText"
        img = self.getImg(REQUEST)
        oTeaserContainer = self.getParentNode()
        bgcolor_title = oTeaserContainer.getObjProperty('attr_bgcolor_title',REQUEST)
        if REQUEST.has_key('bgcolor_title'):
          bgcolor_title = REQUEST['bgcolor_title']
        bgcolor_text = oTeaserContainer.getObjProperty('attr_bgcolor_text',REQUEST)
        if REQUEST.has_key('bgcolor_text'):
          bgcolor_text = REQUEST['bgcolor_text']
        # Render <html>-presentation.
        if img is not None and \
           img.get_size() > 0 and \
           len(s_title) == 0:
          imgclass = bgcolor_title
          html = '<table cellspacing="0" cellpadding="0" border="0"'
          if bgcolor_text:
            html = html + 'class="%s"'%bgcolor_text
          html = html + '>'
          html = html + '<tr>'
          html = html + '<td align="%s">%s</td>'%(textalign,self.renderDisplaytype(displaytype,imgattr,imghiresattr,imgalign,imgurl,imgthumb,imgspecial,imgclass,text,textalign,textformat,textclass,REQUEST))
          html = html + '</tr>'
          html = html + '</table>'
        else:
          html = self.rendershort_default(self,ob=self,url=url,target=target,title=title,text=text,img=img,displaytype=displaytype,bgcolor_title=bgcolor_title,bgcolor_text=bgcolor_text,REQUEST=REQUEST)
        # Return <html>-presentation.
        return html

###################################################################################################
